==> jc-1.4.0.tar.gz: soot/options/SIOptions.h <==
// public class soot.options.SIOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d57c748234181c8f soot_options_SIOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_SIOptions_H_
#define _JC_soot_options_SIOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_SIOptions$sub_refs	_jc_soot_options_SIOptions$sub_refs;
typedef struct _jc_soot_options_SIOptions$sub_nonrefs	_jc_soot_options_SIOptions$sub_nonrefs;
typedef struct _jc_soot_options_SIOptions$refs	_jc_soot_options_SIOptions$refs;
typedef struct _jc_soot_options_SIOptions$nonrefs	_jc_soot_options_SIOptions$nonrefs;
typedef struct _jc_soot_options_SIOptions$object	_jc_soot_options_SIOptions$object;

typedef struct _jc_soot_options_SIOptions$fields_struct	_jc_soot_options_SIOptions$fields_struct;
typedef const struct _jc_soot_options_SIOptions$vmethods	_jc_soot_options_SIOptions$vmethods;
typedef const struct _jc_soot_options_SIOptions$vtable	_jc_soot_options_SIOptions$vtable;
typedef const struct _jc_soot_options_SIOptions$vtype	_jc_soot_options_SIOptions$vtype;

// Class fields structure
struct _jc_soot_options_SIOptions$fields_struct {
	jint	allowed__5fmodifier__5fchanges__5fnone;
	jint	allowed__5fmodifier__5fchanges__5fsafe;
	jint	allowed__5fmodifier__5fchanges__5funsafe;
};
extern _jc_soot_options_SIOptions$fields_struct _jc_soot_options_SIOptions$class_fields;

// Constructors
extern void _jc_soot_options_SIOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_SIOptions$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_soot_options_SIOptions$method$allowed__5fmodifier__5fchanges$992954724bd3d1a3(_jc_env *, struct _jc_soot_options_SIOptions$object *);
extern jboolean _jc_soot_options_SIOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_SIOptions$object *);
extern jfloat _jc_soot_options_SIOptions$method$expansion__5ffactor$1113807716ff9d05(_jc_env *, struct _jc_soot_options_SIOptions$object *);
extern jboolean _jc_soot_options_SIOptions$method$insert__5fnull__5fchecks$a3d5d639bec3a609(_jc_env *, struct _jc_soot_options_SIOptions$object *);
extern jboolean _jc_soot_options_SIOptions$method$insert__5fredundant__5fcasts$34d18a903f88707c(_jc_env *, struct _jc_soot_options_SIOptions$object *);
extern jint _jc_soot_options_SIOptions$method$max__5fcontainer__5fsize$d1002cc70c90ab9a(_jc_env *, struct _jc_soot_options_SIOptions$object *);
extern jint _jc_soot_options_SIOptions$method$max__5finlinee__5fsize$65167c3701a68aff(_jc_env *, struct _jc_soot_options_SIOptions$object *);
extern jboolean _jc_soot_options_SIOptions$method$rerun__5fjb$12229b5453fc3ed0(_jc_env *, struct _jc_soot_options_SIOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_SIOptions$method_info$allowed__5fmodifier__5fchanges$992954724bd3d1a3;
extern _jc_method _jc_soot_options_SIOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_SIOptions$method_info$expansion__5ffactor$1113807716ff9d05;
extern _jc_method _jc_soot_options_SIOptions$method_info$insert__5fnull__5fchecks$a3d5d639bec3a609;
extern _jc_method _jc_soot_options_SIOptions$method_info$insert__5fredundant__5fcasts$34d18a903f88707c;
extern _jc_method _jc_soot_options_SIOptions$method_info$max__5fcontainer__5fsize$d1002cc70c90ab9a;
extern _jc_method _jc_soot_options_SIOptions$method_info$max__5finlinee__5fsize$65167c3701a68aff;
extern _jc_method _jc_soot_options_SIOptions$method_info$rerun__5fjb$12229b5453fc3ed0;

// Virtual methods structure
struct _jc_soot_options_SIOptions$vmethods {
	jint	(*allowed__5fmodifier__5fchanges$992954724bd3d1a3)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
	jfloat	(*expansion__5ffactor$1113807716ff9d05)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
	jboolean	(*insert__5fnull__5fchecks$a3d5d639bec3a609)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
	jboolean	(*insert__5fredundant__5fcasts$34d18a903f88707c)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
	jint	(*max__5fcontainer__5fsize$d1002cc70c90ab9a)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
	jint	(*max__5finlinee__5fsize$65167c3701a68aff)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
	jboolean	(*rerun__5fjb$12229b5453fc3ed0)(_jc_env *, struct _jc_soot_options_SIOptions$object *);
};

// Vtable
struct _jc_soot_options_SIOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_SIOptions$vmethods	soot_options_SIOptions;
};

// Vtype
struct _jc_soot_options_SIOptions$vtype {
	_jc_type			type;
	_jc_soot_options_SIOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_SIOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_SIOptions$refs {
    _jc_soot_options_SIOptions$sub_refs	soot_options_SIOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_SIOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_SIOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_SIOptions$sub_nonrefs	soot_options_SIOptions;
};

// Object instance structure
struct _jc_soot_options_SIOptions$object {
	_jc_soot_options_SIOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_SIOptions$vtype	*vtype;
	_jc_soot_options_SIOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_SIOptions$vtype _jc_soot_options_SIOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_SIOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_SIOptions$class_object;

#endif	/* _JC_soot_options_SIOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/SIOptions.h <==
// public class soot.options.SIOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d57c748234181c8f soot_options_SIOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_SIOptions_H_
#define _JC_soot_options_SIOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_SIOptions$sub_refs	_jc_soot_options_SIOptions$sub_refs;
typedef struct _jc_soot_options_SIOptions$sub_nonrefs	_jc_soot_options_SIOptions$sub_nonrefs;
typedef struct _jc_soot_options_SIOptions$refs	_jc_soot_options_SIOptions$refs;
typedef struct _jc_soot_options_SIOptions$nonrefs	_jc_soot_options_SIOptions$nonrefs;
typedef struct _jc_soot_options_SIOptions$object	_jc_soot_options_SIOptions$object;

typedef struct _jc_soot_options_SIOptions$fields_struct	_jc_soot_options_SIOptions$fields_struct;
typedef const struct _jc_soot_options_SIOptions$vmethods	_jc_soot_options_SIOptions$vmethods;
typedef const struct _jc_soot_options_SIOptions$vtable	_jc_soot_options_SIOptions$vtable;
typedef const struct _jc_soot_options_SIOptions$vtype	_jc_soot_options_SIOptions$vtype;

// Class fields structure
struct _jc_soot_options_SIOptions$fields_struct {
	jint	allowed__5fmodifier__5fchanges__5fnone;
	jint	allowed__5fmodifier__5fchanges__5fsafe;
	jint	allowed__5fmodifier__5fchanges__5funsafe;
};
extern _jc_soot_options_SIOptions$fields_struct _jc_soot_options_SIOptions$class_fields;

// Constructors
extern void _jc_soot_options_SIOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_SIOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_options_SIOptions$method$allowed__5fmodifier__5fchanges$992954724bd3d1a3(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SIOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
extern jfloat _jc_soot_options_SIOptions$method$expansion__5ffactor$1113807716ff9d05(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SIOptions$method$insert__5fnull__5fchecks$a3d5d639bec3a609(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SIOptions$method$insert__5fredundant__5fcasts$34d18a903f88707c(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_options_SIOptions$method$max__5fcontainer__5fsize$d1002cc70c90ab9a(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_options_SIOptions$method$max__5finlinee__5fsize$65167c3701a68aff(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SIOptions$method$rerun__5fjb$12229b5453fc3ed0(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_SIOptions$method_info$allowed__5fmodifier__5fchanges$992954724bd3d1a3;
extern _jc_method _jc_soot_options_SIOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_SIOptions$method_info$expansion__5ffactor$1113807716ff9d05;
extern _jc_method _jc_soot_options_SIOptions$method_info$insert__5fnull__5fchecks$a3d5d639bec3a609;
extern _jc_method _jc_soot_options_SIOptions$method_info$insert__5fredundant__5fcasts$34d18a903f88707c;
extern _jc_method _jc_soot_options_SIOptions$method_info$max__5fcontainer__5fsize$d1002cc70c90ab9a;
extern _jc_method _jc_soot_options_SIOptions$method_info$max__5finlinee__5fsize$65167c3701a68aff;
extern _jc_method _jc_soot_options_SIOptions$method_info$rerun__5fjb$12229b5453fc3ed0;

// Virtual methods structure
struct _jc_soot_options_SIOptions$vmethods {
	jint	(*allowed__5fmodifier__5fchanges$992954724bd3d1a3)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
	jfloat	(*expansion__5ffactor$1113807716ff9d05)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*insert__5fnull__5fchecks$a3d5d639bec3a609)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*insert__5fredundant__5fcasts$34d18a903f88707c)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
	jint	(*max__5fcontainer__5fsize$d1002cc70c90ab9a)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
	jint	(*max__5finlinee__5fsize$65167c3701a68aff)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*rerun__5fjb$12229b5453fc3ed0)(_jc_env *, struct _jc_soot_options_SIOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_SIOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_SIOptions$vmethods	soot_options_SIOptions;
};

// Vtype
struct _jc_soot_options_SIOptions$vtype {
	_jc_type			type;
	_jc_soot_options_SIOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_SIOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_SIOptions$refs {
    _jc_soot_options_SIOptions$sub_refs	soot_options_SIOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_SIOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_SIOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_SIOptions$sub_nonrefs	soot_options_SIOptions;
};

// Object instance structure
struct _jc_soot_options_SIOptions$object {
	_jc_soot_options_SIOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_SIOptions$vtype	*vtype;
	_jc_soot_options_SIOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_SIOptions$vtype _jc_soot_options_SIOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_SIOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_SIOptions$class_object;

#endif	/* _JC_soot_options_SIOptions_H_ */
